# FSion

__FSion__ (_fusion_: _`/ˈfjuʒən/`_) is a library designed to expose
filesystem-like API's from various backends (Google Drive, S3, GCS, local
filesystem etc.)

> [!WARNING]
> The library is in it's very early stages of development. It's a pet project
> of mine, and as of current I don't anticipate dedicating significant time or
> resources to its ongoing development. It's not recommended for production, so
> use it at your own risk.
